@@ -36,10 +36,22 @@ Test script path is 'test/test_ep_flux.rb' in expand dir of gphys.tar.gz.
       * get the gravitational acceleration in surface.
     * ((<g_forces=>))
       * set the gravitational acceleration in surface.
+    * ((<p00>))
+      * get the reference surface pressure.
+    * ((<p00=>))
+      * set the reference surface pressure.
+    * ((<cp>))
+      * get the the specific heat at constant pressure of the atmosphere.
+    * ((<cp=>))
+      * set the the specific heat at constant pressure of the atmosphere.
+    * ((<gas_const>))
+      * get the specific heat at constant pressure of the atmosphere.
+    * ((<gas_const=>))
+      * set the specific heat at constant pressure of the atmosphere.
     * ((<get_constants>))
-      * get the scale height, radius of planet, rotation period of planet.
+      * get the module variables
     * ((<set_constants>))
-      * set the scale height, radius of planet, rotation period of planet.
+      * set the module variables
     * ((<make_gphys>))
       * convert ((<Axis>)) to ((<GPhys>)).
     * ((<to_w_if_omega>))
@@ -62,12 +74,8 @@ Test script path is 'test/test_ep_flux.rb' in expand dir of gphys.tar.gz.
     * ((<preparate_for_strm_rmean>))
       * preparate for ((<strm_rmean>)) 
   * ((<Constants:>))
-    * ((<C_p>))
-      * specific heat at constant pressure of the earth's atmosphere. 
-        C_p = 1004 [J.K-1.kg-1]
-    * ((<R>))
-      * gas constant per unit mass for dry air of the earth.
-        R = 287 [J.K-1.kg-1]
+    * ((<Deriv_methods>))
+      * derivative method names.
         
 =module NumRu::GPhys::EP_Flux
 
@@ -75,7 +83,7 @@ Module functions of EP_Flux Operater for GPhys.
 
 ==Functions:
 
----ep_full_sphere(gp_u, gp_v, gp_w_or_omega, gp_temp_or_theta, flag(temp_or_theta))
+---ep_full_sphere(gp_u, gp_v, gp_w_or_omega, gp_temp_or_theta, flag_temp_or_theta, xyzdims=[0,1,2])
 
     Calculate Eliassen-Palm Flux(EP-Flux) from full set equations on the 
     spherical coordinate. this method calculates EP-Flux from 4 GPhys objects,
@@ -91,6 +99,11 @@ Module functions of EP_Flux Operater for GPhys.
     * gp_w_or_omega (GPhys): a GPhys which data is W or Omega. if you give 
       gp_omega, convert to W in this method and calculate EP-Flux.
     * gp_temp_or_theta (GPhys): a GPhys which data is T or Theta.
+    * xyzdims (Array): an Array which represents location of upper gphyses's 
+                       coordinate. if coordinate configuration is 
+                       (longitude, latitude, z), then xyzdims = [0, 1, 2].
+                       else if coordinate configuration is 
+                       (z, latitude, longitude), then xyzdims = [2, 1, 0].
 
     RETURN VALUE
     * epflx_y (GPhys): EP-Flux y-component. it is on the merdional hoge.
@@ -164,7 +177,7 @@ Module functions of EP_Flux Operater for GPhys.
     RETURN VALUE
     * radius (UNumeric)
 
----radius=(r)
+---radius=(a)
 
    set a value of the radius of the planet.
 
@@ -201,18 +214,67 @@ Module functions of EP_Flux Operater for GPhys.
     RETURN VALUE
     * nil
 
+---p00
+
+   return a value of the reference surface pressure.
+   default value is "1.0E5 Pa".
+
+    RETURN VALUE
+    * reference surface pressure (UNumeric)
+
+---p00=(p00)
+
+   set a value of the reference surface pressure.
+
+    RETURN VALUE
+    * nil
+
+---cp
+
+   return a value of the specific heat at constant pressure of the atmosphere.
+   default value is "1004.0[J.K-1.kg-1]"
+
+    RETURN VALUE
+    * reference surface pressure (UNumeric)
+
+---cp=(cp)
+
+   set a value of the specific heat at constant pressure of the atmosphere.
+
+    RETURN VALUE
+    * nil
+
+---gas_const
+
+   return a value of the gas constant divided by molecular mass.
+   default value is "287.0[J.K-1.kg-1]".
+
+    RETURN VALUE
+    * reference surface pressure (UNumeric)
+
+---gas_const=(r)
+
+   set a value of the gas constant divided by molecular mass.
+
+    RETURN VALUE
+    * nil
+
 ---get_constants
 
-   return  values of the scale height, radius, rotation period, and 
-   gravitational acceleration.
+   return  values of the scale height, radius, rotation period, 
+   gravitational acceleration, reference surface pressure, specific heat,
+   gas constant.
 
     RETURN VALUE
     * scale height (UNumeric)
     * radius (UNumeric)
     * rotation period (UNumeric)
     * gravitational acceleration (UNumeric)
+    * reference surface pressure (UNumeric)
+    * specific heat at constant pressure of the atmosphere (UNumeric)
+    * gas constant divided by molecular mass (UNumeric)
 
----set_constants(scale_height, radius, rot_period, g_forces)
+---set_constants(scale_height, radius, rot_period, g_forces, p00, cp, gas_const)
 
    set values of the scale height, radius, rotation period, and gravitational 
    acceleration.
@@ -222,6 +284,9 @@ Module functions of EP_Flux Operater for GPhys.
     * radius (UNumeric)
     * rotation period (UNumeric)
     * gravitational acceleration (UNumeric)
+    * reference surface pressure (UNumeric)
+    * specific heat at constant pressure of the atmosphere (UNumeric)
+    * gas constant divided by molecular mass (UNumeric)
 
     RETURN VALUE
     * nil
@@ -400,13 +465,9 @@ Module functions of EP_Flux Operater for GPhys.
 
 ==Constants:
 
----C_p
+---Deriv_methods
 
-    specific heat at constant pressure of the earth's atmosphere [J.K-1.kg-1]
-
----R
-
-    gas constant per unit mass for dry air of the earth [J.K-1.kg-1]
+    derivative method name [ 'cderiv', 'threepoint_O2nd_deriv' ]
 
 =end
 ############################################################
@@ -419,19 +480,26 @@ module NumRu
       extend  Misc::EMath
 
       #<<< module constants >>>
-      C_p = 1004.0 # specific heat at constant pressure of the earth's atmosphere [J.K-1.kg-1]
-      R   = 287.0  # gas constant per unit mass for dry air of the earth [J.K-1.kg-1]
+#      C_p = 1004.0 # specific heat at constant pressure of the earth's atmosphere [J.K-1.kg-1]
+#      R   = 287.0  # gas constant per unit mass for dry air of the earth [J.K-1.kg-1]
       Deriv_methods = [ 'cderiv', 'threepoint_O2nd_deriv' ] # list of derivatave method
 
       #<<< module variable >>>
-      @@scale_height = UNumeric.new(7000,  "m")   # log-pressure scale height
-      @@radius       = UNumeric.new(6.37E6,"m")   # radius of the planet
-      @@rot_period   = UNumeric.new(8.64E4,"s")   # rotation period of the planet
-      @@g_forces     = UNumeric.new(9.81,"m.s-2") # gravitational acceleration in the surface
-      @@p00          = UNumeric.new(1.0E5,"Pa")   # reference surface pressure
+      @@scale_height = UNumeric.new(7000,  "m") # log-pressure scale height
+      @@radius       = UNumeric.new(6.37E6,"m") # radius of the planet
+      @@rot_period   = UNumeric.new(8.64E4,"s") # rotation period of the planet
+      @@g_forces     = UNumeric.new(9.81,"m.s-2") 
+                                    # gravitational acceleration in the surface
+      @@p00          = UNumeric.new(1.0E5,"Pa") # reference surface pressure
+      @@cp           = UNumeric.new(1004.0, "J.K-1.kg-1")
+#      @@cp = 1004.0
+                                           # specific heat at constant pressure
+      @@gas_const    = UNumeric.new(287.0, "J.K-1.kg-1")
+#      @@gas_const = 287.0
+                                           # gas constant per molecular mass
       @@deriv_method = Proc.new{|*args|
         GPhys::Derivative::threepoint_O2nd_deriv(*args)
-      }                                           # deriv_method. default method is three*
+      }                                    # deriv_method. default method is three*
 
       module_function
 
@@ -446,8 +514,8 @@ module NumRu
       def radius
 	@@radius
       end
-      def radius=(r)
-	@@radius = r
+      def radius=(a)
+	@@radius = a
 	return nil
       end
       def rot_period
@@ -464,18 +532,40 @@ module NumRu
 	@@rot_period = rp
 	return nil
       end
-      def p00  # note that surface pressure cannot be changeed, only read.
+      def p00
 	@@p00
       end
-      def set_constants(scale_height, radius, rot_period, g_forces)
+      def p00=(p00)
+	@@p00 = p00
+	return nil
+      end
+      def cp
+	@@cp
+      end
+      def cp=(cp)
+	@@cp = cp
+	return nil
+      end
+      def gas_const
+	@@gas_const
+      end
+      def gas_const=(r)
+	@@gas_const = r
+	return nil
+      end
+      def set_constants(scale_height, radius, rot_period, g_forces, p00, cp, gas_const)
 	@@scale_height = scale_height
 	@@radius       = radius
 	@@rot_period   = rot_period
 	@@g_forces     = g_forces
+	@@p00          = p00
+	@@cp           = cp
+	@@gas_const    = gas_const
 	return nil
       end
       def get_constants
-	return @@scale_height, @@radius, @@rot_period, @@g_forces
+	return @@scale_height, @@radius, @@rot_period, @@g_forces, 
+                                                       @@p00, @@cp, @@gas_const
       end
 
       #<<< derivation method  >>> ---------------------------------------------
@@ -654,7 +744,7 @@ module NumRu
 	if flag_temp_or_theta
 	  gp_un = gp_t.data.units
 	  gp_t = gp_t.convert_units(Units.new("K"))
-	  gp_t = gp_t*exp((R/C_p)*z/@@scale_height)
+	  gp_t = gp_t*exp((@@gas_const/@@cp)*z/@@scale_height)
 	  gp_t.data.set_att('long_name', "Potential Temperature")
 	end
 	return gp_t
