@@ -336,6 +336,34 @@ module NumRu
       end
       alias shape shape_current
 
+      def cyclic_ext(dim_or_dimname, modulo)
+	# Cyclic extention to push the first element after the last element
+        # if appropriate.
+
+	# <<developper's memo by horinout, 2005/01>> 
+	# in future modulo should be read based on conventions if nil
+
+	vx = coord(dim_or_dimname)
+	return self if vx.length <= 1
+
+	width = (vx[-1].val - vx[0].val).abs
+	dx = width / (vx.length-1)
+	eps = 1e-4
+	modulo = modulo.abs
+	extendible = ( ((width+dx) - modulo).abs < eps*modulo )
+
+	if extendible
+	  dim = @grid.dim_index(dim_or_dimname)
+	  newgp = self.copy[ false, [0...vx.length, 0], *([true]*(rank-1-dim)) ]
+	  vx = newgp.coord(dim)
+	  vx[-1] = vx[-1].val + modulo
+	  newgp.axis(dim).set_pos(vx)
+	  return newgp
+	else
+	  return self
+	end
+      end
+
       ############## < private methods > ##############
 
       private
@@ -493,6 +521,10 @@ if $0 == __FILE__
    gpz3_cext = gpz3[ [0...sp[0],0], false ]
    p gpz3_cext.coord(0).val, gpz3_cext.val
 
+   print "cyclic extention if appropriate\n"
+   gpz3_cext = gpz3.cyclic_ext(0,10.0)
+   p gpz3_cext.coord(0).val, gpz3_cext.val
+
    print "axis to gphys\n"
    ax = gpz3.axis(1)
    p ax.to_gphys
