@@ -60,6 +60,7 @@ module NumRu
 
       def set_axis(dim_or_dimname,ax)
 	 @axes[ ax_dim(dim_or_dimname)[1] ] = ax
+	 self
       end
 
       def set_lost_axes( lost )
@@ -289,7 +290,9 @@ module NumRu
 	for i in 0...rank
 	  axes[i] = @axes[dims[i]]
 	end
-	Grid.new(*axes)
+	grid = Grid.new(*axes)
+	grid.set_lost_axes( lost_axes )
+	grid
       end
 
       # Define operations along each axis --- The following defines
