@@ -478,6 +478,7 @@ These methods returns a NArray (not a VArray).
       end
 
       def [](*slicer)
+	 slicer = __rubber_expansion( slicer )
 	 mapping = SubsetMapping.new(self.shape_current, slicer)
 	 VArray.new.initialize_mapping(mapping, self)
       end
@@ -485,6 +486,7 @@ These methods returns a NArray (not a VArray).
       def []=(*args)
 	 val = args.pop
 	 slicer = args
+	 slicer = __rubber_expansion( slicer )
 	 if val.is_a?(VArray)
 	    val = val.val
 	 else
@@ -532,7 +534,7 @@ These methods returns a NArray (not a VArray).
 	  when Array
 	    na = NArray.to_na(other)
 	    c_other = VArray.new(na, oattr, self.name)
-	  when NArray
+	  when NArray, NArrayMiss
 	    c_other = VArray.new(other, oattr, self.name)
 	  else
 	    raise "Cannot coerse #{other.class}"
@@ -777,6 +779,20 @@ These methods returns a NArray (not a VArray).
 
       ## < private methods >
       private
+      def __rubber_expansion( args )
+	if (id = args.index(false))  # substitution into id
+          # false is incuded
+	  alen = args.length
+	  if args.rindex(false) != id
+	    raise ArguemntError,"only one rubber dimension is permitted"
+	  elsif alen > rank+1
+	    raise ArgumentError, "too many args"
+	  end
+	  ar = ( id!=0 ? args[0..id-1] : [] )
+	  args = ar + [true]*(rank-alen+1) + args[id+1..-1]
+	end
+	args
+      end
       def __check_ary_class(narray)
 	 case narray
 	 when NArray, NArrayMiss, nil
