@@ -194,43 +194,60 @@ p "##############################################################"
 p "####         << Section 1 -- test accesor method >>       ####"
 
 # get DEFAULT constants
-default_h      = GPhys::EP_Flux::scale_height
-default_radius = GPhys::EP_Flux::radius
-default_rot    = GPhys::EP_Flux::rot_period
-default_g      = GPhys::EP_Flux::g_forces
+default_h         = GPhys::EP_Flux::scale_height
+default_radius    = GPhys::EP_Flux::radius
+default_rot       = GPhys::EP_Flux::rot_period
+default_g         = GPhys::EP_Flux::g_forces
+default_p00       = GPhys::EP_Flux::p00
+default_cp        = GPhys::EP_Flux::cp
+default_gas_const = GPhys::EP_Flux::gas_const
 
 # set module constants
 GPhys::EP_Flux::scale_height = UNumeric.new(1, "m")
 GPhys::EP_Flux::radius       = UNumeric.new(1, "")
 GPhys::EP_Flux::rot_period   = UNumeric.new(10, "rad/s")
 GPhys::EP_Flux::g_forces     = UNumeric.new(1, "m.s-2")
+GPhys::EP_Flux::p00          = UNumeric.new(1, "Pa")
+GPhys::EP_Flux::cp           = UNumeric.new(1, "")
+GPhys::EP_Flux::gas_const    = UNumeric.new(1, "")
 
 # get GIVEN constants
-h      = GPhys::EP_Flux::scale_height
-radius = GPhys::EP_Flux::radius
-rot    = GPhys::EP_Flux::rot_period
-g      = GPhys::EP_Flux::g_forces
+h         = GPhys::EP_Flux::scale_height
+radius    = GPhys::EP_Flux::radius
+rot       = GPhys::EP_Flux::rot_period
+g         = GPhys::EP_Flux::g_forces
+p00       = GPhys::EP_Flux::p00
+cp        = GPhys::EP_Flux::cp
+gas_const = GPhys::EP_Flux::gas_const
 
 # compare default and given values.
 fm = "%-15s%15s%17s%s"   # format of output 
 
 p "*********** compare default and given values ***********"
 printf(fm, "  <name>",      "<default value>",    "<given value>","\n")
-printf(fm, "  scale_height",  default_h.to_s,       h.to_s,       "\n")
-printf(fm, "  radius",        default_radius.to_s,  radius.to_s,  "\n")
-printf(fm, "  rot_period",    default_rot.to_s,     rot.to_s,     "\n")
-printf(fm, "  g_forces",      default_g.to_s,       g.to_s,       "\n")
+printf(fm, "  scale_height",  default_h.to_s,         h.to_s,         "\n")
+printf(fm, "  radius",        default_radius.to_s,    radius.to_s,    "\n")
+printf(fm, "  rot_period",    default_rot.to_s,       rot.to_s,       "\n")
+printf(fm, "  g_forces",      default_g.to_s,         g.to_s,         "\n")
+printf(fm, "  p00",           default_p00.to_s,       p00.to_s,       "\n")
+printf(fm, "  cp",            default_cp.to_s,        cp.to_s,        "\n")
+printf(fm, "  gas_const",     default_gas_const.to_s, gas_const.to_s, "\n")
 
 # test ((<set_constants>)) and ((<get_constants>))
-GPhys::EP_Flux::set_constants(default_h, default_radius, default_rot, default_g)
+GPhys::EP_Flux::set_constants(default_h, default_radius, default_rot, 
+                              default_g, default_p00, default_cp, 
+                                                      default_gas_const)
                                 # clean up after tests (backto default values)
-h, radius, rot, g = GPhys::EP_Flux::get_constants
+h, radius, rot, g, p00, cp, gas_const = GPhys::EP_Flux::get_constants
 p "*** test ((<set_constants>)) and ((<get_constants>)) ***"
 printf(fm, "  <name>",     "<set_constants>",  "<get_constants>", "\n")
 printf(fm, "  scale_height",  default_h.to_s,       h.to_s,         "\n")
 printf(fm, "  radius",        default_radius.to_s,  radius.to_s,    "\n")
 printf(fm, "  rot_period",    default_rot.to_s,     rot.to_s,       "\n")
 printf(fm, "  g_forces",      default_g.to_s,       g.to_s,       "\n")
+printf(fm, "  p00",           default_p00.to_s,     p00.to_s,     "\n")
+printf(fm, "  cp",            default_cp.to_s,        cp.to_s,        "\n")
+printf(fm, "  gas_const",     default_gas_const.to_s, gas_const.to_s, "\n")
 
 
 p "##############################################################"
@@ -274,10 +291,10 @@ p "####       << Section 3 -- test calculate method >>       ####"
 ### constants
 GPhys::EP_Flux::scale_height = UNumeric.new(1, "m")
 GPhys::EP_Flux::radius       = UNumeric.new(1, "m")
-h, radius, rot = GPhys::EP_Flux::get_constants
+h, radius, rot, = GPhys::EP_Flux::get_constants
 h = h.val; radius = radius.val; rot = rot.val
 p00 = GPhys::EP_Flux::p00.convert( Units.new("mb") ).val
-kappa = GPhys::EP_Flux::R / GPhys::EP_Flux::C_p
+kappa = (GPhys::EP_Flux::gas_const / GPhys::EP_Flux::cp).val
 
 ### make NArray of axis
 nlon = 100; nlat = 50; nz = 10
@@ -492,8 +509,7 @@ va_f_z = VArray.new( na_f_z,
 gp_f_phi = GPhys.new(grid, va_f_phi)
 gp_f_z = GPhys.new(grid, va_f_z)
 
-
-kappa  = GPhys::EP_Flux::R / GPhys::EP_Flux::C_p 
+kappa = (GPhys::EP_Flux::gas_const / GPhys::EP_Flux::cp).val
 p00  = GPhys::EP_Flux::p00
 scale_height  = GPhys::EP_Flux::scale_height
 rot_period  = GPhys::EP_Flux::rot_period
